import yaml
import json
from typing import Dict
from pathlib import Path


class Config:
    def __init__(self, config_items: Dict) -> None:
        for key, value in config_items.items():
            attr_value = Config(value) if isinstance(value, dict) else value
            self.__setattr__(key, attr_value)

    @staticmethod
    def load_from_yml(path: Path):
        with open(path) as f:
            return Config(yaml.load(f, Loader=yaml.FullLoader))

    @staticmethod
    def load_from_json(path: Path):
        with open(path) as f:
            return Config(json.load(f))



from pathlib import Path
from manageconfig import Config

JSON_FILE = Path(Path(__file__).parent, 'config.json')


def test_sanity():
    conf = Config.load_from_json(JSON_FILE)

    assert conf.version == '1.0.0'
    assert conf.dependencies == [
        "express",
        "body-parser",
        "mongodb"
    ]
    assert conf.scripts.start == 'node app.js'
    assert type(conf.numberKey) == int
    assert conf.numberKey == 123
    assert not conf.private



from pathlib import Path
from manageconfig import Config

YAML_FILE = Path(Path(__file__).parent, 'config.yml')


def test_sanity():
    conf = Config.load_from_yml(YAML_FILE)

    assert conf.key == 'value'
    assert conf.mysqldatabase.hostname == 'localhost'
    assert type(conf.mysqldatabase.port) == int
    assert not conf.booleanValue
